# COSA
Computer Optic Semantics

to install run:

`pip install cosabot`

## Working environment:

Create a `Conda` enviromnent and install the dependencies:

```bash
conda env create --file environment.yaml
conda activate cosa
pip install -r requirements_dev.txt
```
